Struct NonZeroVbi
pub struct NonZeroVbi(NonZeroU32);Expand description
Non-zero Variable Byte Integer.
Tuple Fields
0: NonZeroU32Implementations
impl NonZeroVbi
impl NonZeroVbi
pub const MIN: Self
pub const MIN: Self
The minimum non-zero value (a.k.a. 1).
pub const MAX: Self
pub const MAX: Self
The maximum value.
pub const MAX_USIZE: usize = 268_435_455usize
pub const MAX_USIZE: usize = 268_435_455usize
The maximum usize value that can be represented as a non-zero VBI.
pub const fn new(value: u32) -> Option<Self>
pub const fn new(value: u32) -> Option<Self>
Creates a new non-zero VBI, returning None if the value is zero.
pub const fn from_vbi(value: Vbi) -> Option<Self>
pub const fn from_vbi(value: Vbi) -> Option<Self>
Creates a new non-zero VBI, returning None if the value is zero.
pub const fn encoded_len(self) -> usize
pub const fn encoded_len(self) -> usize
Returns the number of bytes needed to encode this non-zero VBI.